# indoxRag/__init__.py
# from .indoxRag import IndoxRetrievalAugmentation

# from .cag import CAG

# import importlib.metadata

# __version__ = importlib.metadata.version("indoxRag")
__version__ = "0.1.1"
